@@ -4,8 +4,8 @@ __author__ = 'Timo Kats'
 
 # local imports
 
-from lib.lexical_analysis import *
-from lib.split import *
+from redex.lib.lexical_analysis import *
+from redex.lib.split import *
 
 # main functionalities
 
@@ -33,6 +33,6 @@ def find(query, string, split=' ', granularity=1, format='string', threads=2):
 def info():
     print('\n---')
     print('    ^ ^          Description:        Python library for readable regex.')
-    print('("\(-_-)/")      Version:            0.0.3') 
+    print('("\(-_-)/")      Version:            0.0.4') 
     print(' )(  O  )(       Author:             Timo Kats')
     print('((...)(...))     Last updated:       02/07/2023', end='\n---\n\n')
